@@ -1,8 +1,10 @@
 package config
 
 import (
-	"io/ioutil"
+	"fmt"
+	"os"
 	"path/filepath"
+	"strings"
 
 	"gopkg.in/yaml.v2"
 )
@@ -20,12 +22,17 @@ type Plugin struct {
 	Scopes      []string `yaml:"scopes"`
 	Args        []string `yaml:"args"`
 	ShortCut    string   `yaml:"shortCut"`
+	Pipes       []string `yaml:"pipes"`
 	Description string   `yaml:"description"`
 	Command     string   `yaml:"command"`
 	Confirm     bool     `yaml:"confirm"`
 	Background  bool     `yaml:"background"`
 }
 
+func (p Plugin) String() string {
+	return fmt.Sprintf("[%s] %s(%s)", p.ShortCut, p.Command, strings.Join(p.Args, " "))
+}
+
 // NewPlugins returns a new plugin.
 func NewPlugins() Plugins {
 	return Plugins{
@@ -40,7 +47,7 @@ func (p Plugins) Load() error {
 
 // LoadPlugins loads plugins from a given file.
 func (p Plugins) LoadPlugins(path string) error {
-	f, err := ioutil.ReadFile(path)
+	f, err := os.ReadFile(path)
 	if err != nil {
 		return err
 	}
